#!/bin/bash

# Zenwalk Gnu/Linux build script written for "e17_base"
# Soft Home Page: http://www.enlightenment.org
# Source URL: Enlightenment CVS
# Software's Dependencies: "curl,e17_libs,e17_modules,expat,fontconfig,freetype,libidn,libjpeg,openssl,xorg,zlib"
# Package Maintainer: Michael Verret (AxXium) axxium.zenlnx@gmail.com
# Date of script Revision: Thursday 28 June 2007


#------------------( Unique Package Variables )


SOURCEARCHIVE="e-CVS20070628.tar.bz2"
SOURCEVERSION="CVS20070628"
SOFT='e17_base'
SOFTVERSION='0.16.999.039'		# Obtain the version from the file configure.in
BUILDVERSION='48.4'
ARCH='i686'
CPU='i686'
DOCS="{ABOUT-NLS,AUTHORS,BUGS,COPYING,COPYING-PLAIN,INSTALL,README,TODO}"
#      |-----handy-ruler------------------------------------------------------|
DESC_LINE_01="Evolutionary, next-generation desktop enviornment"
DESC_LINE_02=""
DESC_LINE_03="Development Release 17 of the Enlightenment window manager"
DESC_LINE_04="represents an evolution into the next generation of desktop"
DESC_LINE_05="environments: the desktop shell. DR17 will provide integration"
DESC_LINE_06="between files and your environment in a seamless manner while"
DESC_LINE_07="encompassing a graphically rich and flexible architecture."
DESC_LINE_08="DR17 brings to you a completely new way of visualizing your"
DESC_LINE_09="desktop, based around the Enlightenment Foundation Libraries"
DESC_LINE_10="which were built from the ground up for this task."
DESC_LINE_11="For more information, see: http://enlightenment.org/"


#------------------( Standard Variables & Routines )


REACTOR="$SOFT-$SOFTVERSION"
BUILDIR=$(pwd)
cd $BUILDIR
PACKAGE="$REACTOR-$ARCH-$BUILDVERSION"
DEST="$BUILDIR/$PACKAGE"

rm -rf {$DEST,$DEST.dep,$DEST.md5,$DEST.tgz,$PACKAGE,$PACKAGE.dep,$PACKAGE.md5} 1>/dev/null 2>&1

for file in $SOURCEARCHIVE ; do
  if [ "$(echo $file | grep ".tar.bz2" )" ]; then
      SOURCEDIR="$(basename $file .tar.bz2)"
      rm -rf $SOURCEDIR
      tar jxvf $file
  elif [ "$(echo $file | grep ".tar.gz" )" ]; then
      SOURCEDIR="$(basename $file .tar.gz)"
      rm -rf $SOURCEDIR
      tar zxvf $file
  fi
done

mv $SOURCEDIR $BUILDIR/$REACTOR/
mkdir -p {$DEST,$DEST/usr/doc/$REACTOR,$DEST/install,$DEST/usr/src/$REACTOR}


#------------------( Configuration and Compilation )



cd $REACTOR

    chown -R root:root . 
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="$CFLAGS"

./autogen.sh --prefix=/usr

./configure --prefix=/usr \
  --bindir=/usr/bin \
  --sbindir=/sbin \
  --libexecdir=/usr/libexec \
  --sysconfdir=/etc \
  --sharedstatedir=/usr/com \
  --localstatedir=/var \
  --libdir=/usr/lib \
  --includedir=/usr/include \
  --oldincludedir=/usr/include \
  --datarootdir=/usr/share \
  --infodir=/usr/info \
  --localedir=/usr/share/locale \
  --mandir=/usr/man \
  --docdir=/usr/doc/$REACTOR \
  --htmldir=/usr/doc/$REACTOR/html \
  --dvidir=/usr/doc/$REACTOR/dvi \
  --pdfdir=/usr/doc/$REACTOR/pdf \
  --psdir=/usr/doc/$REACTOR/ps

make -j4
make install DESTDIR=$DEST


#------------------( Add xinitrc.e to tame E17 )


# I wanted this buildscript to just use "cat" to write
# the file, but the text ${HOME} was acting up as you
# can probably imagine.   :)

mkdir -p $DEST/etc/X11/xinit
cp $BUILDIR/xinitrc.e $DEST/etc/X11/xinit
chown 775 $DEST/etc/X11/xinit/xinitrc.e
chmod +x $DEST/etc/X11/xinit/xinitrc.e


#------------------( Remove the default theme )


# The default theme will be moved to the "e17_themes"
# package as an option in case someone likes it.   ;)


( cd $DEST/usr/share/enlightenment/data
  tar -cf themes.tar themes
  bzip2 --best themes.tar
  mv *.tar.bz2 $BUILDIR/
  rm -rf themes
)


#------------------( Add the new theme )


cd $BUILDIR 
mkdir -p  $DEST/usr/share/enlightenment/data/themes
tar -xvjf $BUILDIR/theme-simply_white.tar.bz2
mv $BUILDIR/theme-simply_white/simply-white.edj $DEST/usr/share/enlightenment/data/themes/simply-white.edj
rm -rf mv $BUILDIR/theme-simply_white


#------------------( Add the Zenwalk Customized E17 config files and background )


# You can substitute "axxium" with any regular user on
# the system you are building this package with.  ;)

# Configs for the administrator
cd $BUILDIR
tar -xvjf root.tar.bz2
mv root/ $DEST/root
chown -R root:root $DEST/root/.e

# Configs for all other users
cd $BUILDIR
tar -xvjf zenwalk-defaults.tar.bz2
mv zenwalk-defaults $DEST/etc/enlightenment/zenwalk-defaults
chown -R axxium:users $DEST/etc/enlightenment/zenwalk-defaults/.e
chmod 775 $DEST/etc/enlightenment/zenwalk-defaults/.e

# Zenwalk default Shared backdrop
cd $BUILDIR
tar -xvjf zenwalk-backdrop.tar.bz2
mv zenwalk-backdrop/* $DEST/usr/share/enlightenment/data/backgrounds
rm -rf zenwalk-backdrop


#------------------( Add a CORRECT enlightenment.desktop file for GDM )


# This is so it plays nicely with GDM. ;)


( cd $DEST
  mkdir -p $DEST/etc/X11/dm/Sessions/
)

cat <<EOF >  $DEST/etc/X11/dm/Sessions/enlightenment.desktop
[Desktop Entry]
Encoding=UTF-8
Name=Enlightenment
Comment=Log in using Enlightenment (Version 0.16.999.039)
Type=XSession
Icon=/usr/share/enlightenment/data/images/enlightenment.png
Exec=/etc/X11/xinit/xinitrc.e
TryExec=/etc/X11/xinit/xinitrc.e
GenericName=E17
EOF


#------------------( Ensure the correct permissions )


cat <<EOF >  $DEST/install/doinst.sh
chmod -R 775 /etc/enlightenment/zenwalk-defaults 1>/dev/null 2>&1
EOF


#------------------( Add custom icons )


mkdir -p $DEST/usr/share/icons/hicolor/scalable
( cd $BUILDIR
  tar -xvjf $BUILDIR/custom-icons.tar.bz2
  cd $BUILDIR/custom-icons
  cp -a *.svg $DEST/usr/share/icons/hicolor/scalable
  rm -rf $BUILDIR/custom-icons
)


#------------------( Fix MountPoints Launcher )


( cd $DEST/usr/share
  tar -xvjf $BUILDIR/applications.tar.bz2
)


#------------------( Packaging )


( cd $DEST
   find . | xargs file | grep "executable" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
   find . | xargs file | grep "shared object" | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null
)

( cd $BUILDIR/$REACTOR
rm -rf $DEST/usr/share/doc
mkdir -p $DEST/usr/doc/$REACTOR
cp -a  ABOUT-NLS AUTHORS BUGS COPYING COPYING-PLAIN INSTALL README TODO \
$DEST/usr/doc/$REACTOR
)

( cd $DEST/usr/share/enlightenment
  rm -rf AUTHORS COPYING
)

( cd $DEST/usr/doc/$REACTOR
  mkdir -p html
  mv $DEST/usr/share/enlightenment/doc/* html
  rm -rf $DEST/usr/share/enlightenment/doc
)


cat <<EOF > $DEST/install/slack-desc 
      |-----handy-ruler------------------------------------------------------|
$SOFT: $DESC_LINE_01
$SOFT: $DESC_LINE_02
$SOFT: $DESC_LINE_03
$SOFT: $DESC_LINE_04
$SOFT: $DESC_LINE_05
$SOFT: $DESC_LINE_06
$SOFT: $DESC_LINE_07
$SOFT: $DESC_LINE_08
$SOFT: $DESC_LINE_09
$SOFT: $DESC_LINE_10
$SOFT: $DESC_LINE_11
EOF

cp $BUILDIR/build-$SOFT.sh $DEST/usr/src/$REACTOR/build-$SOFT.sh

cd $DEST
requiredbuilder -z $DEST >> $BUILDIR/$PACKAGE.dep

makepkg -l y -c n ../$PACKAGE.tgz
cd $BUILDIR
rm -rf {$DEST,$REACTOR}

md5sum $PACKAGE.tgz > $PACKAGE.md5